powered by
Discrete Epanechnikov kernel
discrete_epanech(x, z, h)
Returns the value of the associated kernel function according to the target x and the bandwidth h.
the target point at which the density is calculated
the vector of observations
the bandwidth (or smoothing parameter)
# Basic usage of discrete_epanech() to compute a discrete Epanechnikov kernel discrete_epanech(x = 25, z = 1:50, h = 20)
Run the code above in your browser using DataLab