Learn R Programming

kernopt (version 1.0.0)

discrete_triang: Discrete triangular kernel

Description

Discrete triangular kernel

Usage

discrete_triang(x, z, h, a)

Value

Returns the value of the associated kernel function according to the target x and the bandwidth h.

Arguments

x

the target point at which the density is calculated

z

the vector of observations

h

the bandwidth (or smoothing parameter)

a

the integer (positive) parameter that defined the support of the kernel function

Examples

Run this code
# Basic usage of discrete_triang() to compute a Discrete triangular kernel
discrete_triang(x = 25, z = 1:50, h = 10, a = 20)

Run the code above in your browser using DataLab