powered by
Discrete triangular kernel
discrete_triang(x, z, h, a)
Returns the value of the associated kernel function according to the target x and the bandwidth h.
the target point at which the density is calculated
the vector of observations
the bandwidth (or smoothing parameter)
the integer (positive) parameter that defined the support of the kernel function
# Basic usage of discrete_triang() to compute a Discrete triangular kernel discrete_triang(x = 25, z = 1:50, h = 10, a = 20)
Run the code above in your browser using DataLab